@@ -226,8 +226,7 @@ class PyHocaCLI(x2go.X2GoClient):
         """
         # resume a running session
         self.logger('resuming X2Go session: %s' % self.args.resume, loglevel=x2go.loglevel_INFO, )
-        if available_sessions is None:
-            available_sessions = self._X2GoClient__list_sessions(s_hash)
+        available_sessions = self._X2GoClient__list_sessions(s_hash)
         if available_sessions and self.args.resume == 'OLDEST':
             self._auto_resume_oldest(s_hash)
         elif available_sessions and self.args.resume == 'NEWEST':
@@ -385,6 +384,8 @@ class PyHocaCLI(x2go.X2GoClient):
 
         self.auth_attempts = int(self.args.auth_attempts)
 
+        self.non_interactive = bool(self.args.non_interactive)
+
 
         if args.list_profiles:
 
@@ -458,7 +459,9 @@ class PyHocaCLI(x2go.X2GoClient):
                                                            add_to_known_hosts=self.args.add_to_known_hosts,
                                                            profile_name = 'Pyhoca-Client_Session',
                                                            session_type=self.args.session_type,
+                                                           kdrive=self.args.kdrive,
                                                            link=self.args.link,
+                                                           dpi=self.args.dpi,
                                                            xinerama=self.args.xinerama,
                                                            geometry=self.args.geometry,
                                                            pack=self.args.pack,
@@ -472,7 +475,9 @@ class PyHocaCLI(x2go.X2GoClient):
                                                            share_local_folders=self.args.share_local_folders,
                                                            allow_share_local_folders=allow_share_local_folders,
                                                            forward_sshagent=self.args.forward_sshagent,
-                                                           cmd=self.args.command)
+                                                           clipboard=self.args.clipboard_mode,
+                                                           cmd=self.args.command,
+                                                           look_for_keys=self.args.look_for_keys)
 
     def authenticate(self):
         """\
@@ -494,7 +499,12 @@ class PyHocaCLI(x2go.X2GoClient):
         if self.args.force_password:
             force_password_auth = True
 
-        passphrase = None
+        if self.non_interactive:
+            non_interactive = True
+        else:
+            non_interactive = False
+
+        passphrase = self.args.ssh_passphrase
         passphrase_unlock_counter = 3
 
         _username = self.args.username or self._X2GoClient__get_session_username(self.x2go_session_hash)
@@ -514,10 +524,13 @@ class PyHocaCLI(x2go.X2GoClient):
 
                     # show interactive password prompt
                     if force_password_auth and not cmdline_password:
+                        if non_interactive:
+                            _auth_count -= 1
+                            continue
 
                         password = getpass.getpass()
 
-                        # workaround for Python bug: http://bugs.python.org/issue11236
+                        # workaround for Python bug: https://bugs.python.org/issue11236
                         try:
                             if password is not None and '\x03' in password:
                                 raise KeyboardInterrupt()
@@ -542,7 +555,7 @@ class PyHocaCLI(x2go.X2GoClient):
 
                     # x2go.PasswordRequiredException: This exception gets raised if an SSH pubkey is protected by a passphrase
 
-                    if not force_password_auth and passphrase_unlock_counter >= 1:
+                    if not non_interactive and not force_password_auth and passphrase_unlock_counter >= 1:
                         if passphrase == '':
                             self._pyhoca_logger('empty SSH key passphrase (%s), try again...' % self.args.ssh_privkey, loglevel=x2go.loglevel_WARN, )
                         self._pyhoca_logger('unlock SSH key file (%s)' % self.args.ssh_privkey, loglevel=x2go.loglevel_NOTICE, )
@@ -553,7 +566,13 @@ class PyHocaCLI(x2go.X2GoClient):
                         continue
 
                     if not force_password_auth and _auth_count >= 1:
-                        self._pyhoca_logger('unlocking of SSH key failed, proceeding with interactive login', loglevel=x2go.loglevel_WARN, )
+                        if  non_interactive:
+                            self._runtime_error('unlocking of SSH key failed.',
+                                                exitcode=-203)
+                        else:
+                            self._pyhoca_logger('unlocking of SSH key failed, '
+                                                'proceeding with interactive '
+                                                'login', loglevel=x2go.loglevel_WARN, )
                         force_password_auth = True
                         password = None
                         passphrase = None
@@ -570,7 +589,7 @@ class PyHocaCLI(x2go.X2GoClient):
                         self._pyhoca_logger('passwordless login for ,,%s\'\' failed [AuthException]' % _username, loglevel=x2go.loglevel_WARN, )
 
                     # if the previous login attempt was pubkey based, enforce interactive login for the next round...
-                    if not password and _auth_count >= 1:
+                    if not non_interactive and not password and _auth_count >= 1:
                         self._pyhoca_logger('proceeding to interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
                         force_password_auth = True
                         # undo auth counter decrement
@@ -578,12 +597,22 @@ class PyHocaCLI(x2go.X2GoClient):
 
                     # a password was provided via the command line
                     elif password and cmdline_password and _auth_count >= 1:
-                        self._pyhoca_logger('cmdline provided password failed, proceeding to interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_WARN, )
+                        if not non_interactive:
+                            self._pyhoca_logger('cmdline provided password '
+                                                'failed, proceeding to '
+                                                'interactive login for '
+                                                'user ,,%s\'\'' % _username,
+                                                loglevel=x2go.loglevel_WARN, )
+                        else:
+                            self._runtime_error('cmdline provided password '
+                                                'failed.',
+                                                exitcode=-204)
+
                         force_password_auth = True
                         cmdline_password = False
 
                     # else, if the previous attempt was already interactive, offer re-trying
-                    elif force_password_auth and _auth_count >= 1:
+                    elif not non_interactive and force_password_auth and _auth_count >= 1:
                         self._pyhoca_logger('please re-try login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
 
                     passphrase = None
@@ -598,7 +627,8 @@ class PyHocaCLI(x2go.X2GoClient):
                 except x2go.SSHException as e:
 
                     # this bit only captures problems with the SSH key file, other
-                    # SSHExceptions are simply ignored (and we proceed to interactive login)
+                    # SSHExceptions are simply ignored and we proceed to
+                    # interactive login, if non_interactive is NOT set.
 
                     if str(e).lower().startswith('could not deserialize key data')                                          \
                         :
@@ -617,8 +647,11 @@ class PyHocaCLI(x2go.X2GoClient):
                             continue
 
                         if not force_password_auth and _auth_count >= 1:
-
-                            self._pyhoca_logger('unlocking of SSH key failed, proceeding with interactive login', loglevel=x2go.loglevel_WARN, )
+                            if non_interactive:
+                                self._runtime_error('unlocking of SSH key failed.',
+                                                    exitcode=-205)
+                            else:
+                                self._pyhoca_logger('unlocking of SSH key failed, proceeding with interactive login', loglevel=x2go.loglevel_WARN, )
                             force_password_auth = True
                             password = None
                             passphrase = None
@@ -641,13 +674,15 @@ class PyHocaCLI(x2go.X2GoClient):
                         self._runtime_error(str(e), exitcode=253)
 
                     else:
-
-                        self._pyhoca_logger('[SSHException] the following error will be ignored: %s' % str(e), loglevel=x2go.loglevel_WARN)
-                        self._pyhoca_logger('proceeding to interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
-                        force_password_auth = True
-                        password = None
-                        passphrase = None
-                        _auth_count += 1
+                        if non_interactive:
+                            self._runtime_error('[SSHException] the following error occured: %s' % str(e), exitcode=-206)
+                        else:
+                            self._pyhoca_logger('[SSHException] the following error will be ignored: %s' % str(e), loglevel=x2go.loglevel_WARN)
+                            self._pyhoca_logger('proceeding to interactive login for user ,,%s\'\'' % _username, loglevel=x2go.loglevel_NOTICE, )
+                            force_password_auth = True
+                            password = None
+                            passphrase = None
+                            _auth_count += 1
 
                 if not connected and _auth_count <= 0:
                     if self.auth_attempts >= 2:
